﻿Option Strict On
Option Explicit On

Imports System.IO


Public Class Mediendatei

    Private i_Pfad As String
    Private i_Name As String
    Private i_Groesse As String
    Private i_Dateiendung As String
    Private i_Dateityp As String
    Private i_Aufnahmedatum As Date
    Private i_Dateistatus As Boolean

    Public Property Pfad As String
        Get
            Return i_Pfad
        End Get
        Set(value As String)
            i_Pfad = value
            Call Informationen_Update()
        End Set
    End Property

    Public ReadOnly Property Name As String
        Get
            Return i_Name
        End Get
    End Property

    Public ReadOnly Property Groesse As String
        Get
            Return i_Groesse
        End Get
    End Property

    Public ReadOnly Property Dateiendung As String
        Get
            Return i_Dateiendung
        End Get
    End Property

    Public ReadOnly Property Dateityp As String
        Get
            Return i_Dateityp
        End Get
    End Property

    Public ReadOnly Property Aufnahmedatum As Date
        Get
            Return i_Aufnahmedatum
        End Get
    End Property

    Public ReadOnly Property Dateistatus As Boolean
        Get
            Return i_Dateistatus
        End Get
    End Property


    Public Sub New(ByVal p_Pfad As String)
        i_Pfad = p_Pfad
        Call Informationen_Update()
    End Sub

    Public Sub New()

    End Sub

    Private Sub Informationen_Update()
        Call s_Name(i_Pfad)
        Call s_Groesse(i_Pfad)
        Call s_Dateiendung(i_Pfad)
        Call s_Dateityp(i_Dateiendung)
        Call s_Aufnahmedatum(i_Pfad, i_Dateityp)
    End Sub

    Private Sub s_Name(ByVal p_Pfad As String)
        i_Name = Path.GetFileName(p_Pfad) 'Übergibt den Dateinamen des Pfads
    End Sub

    Private Sub s_Groesse(ByVal p_Pfad As String)
        'Format c heißt Tausendertrennzeichen und wenn vorhanden zwei Nachkommastellen
        i_Groesse = Format(Math.Round(My.Computer.FileSystem.GetFileInfo(p_Pfad).Length / 1024, 0), "n") & " kB" 'Dateigröße in kB
    End Sub

    Private Sub s_Dateiendung(ByVal p_Pfad As String)
        i_Dateiendung = Replace(My.Computer.FileSystem.GetFileInfo(p_Pfad).Extension, ".", "").ToUpper 'Ruft die Dateiendung ab und gibt in Großbuchstaben aus
    End Sub

    Private Sub s_Dateityp(ByVal p_Dateiendung As String)
        i_Dateityp = f_Dateiendung_pruefen(p_Dateiendung) 'Prüft ob es sich um ein unterstütztes Dateiformat handelt
    End Sub

    Private Sub s_Aufnahmedatum(ByVal p_Pfad As String, ByVal p_Dateityp As String)
        Dim Temp_Datum As Date
        Dim i_fi As New IO.FileInfo(p_Pfad)


        Select Case p_Dateityp
            Case "Picture"
                Temp_Datum = f_GetPictureCreationDateOf(i_fi)
            Case "Movie"
                Temp_Datum = f_GetMovieCreationDateOf(i_fi)
            Case "NoSupport"
                Temp_Datum = Date.Parse("01.01.1900")
        End Select

        If Temp_Datum = Date.Parse("01.01.1900") Then
            i_Aufnahmedatum = Temp_Datum
            i_Dateistatus = False

        ElseIf Temp_Datum = Date.Parse("02.01.1900") Then
            i_Aufnahmedatum = i_fi.LastWriteTime.Date
            i_Dateistatus = False

        Else
            i_Aufnahmedatum = Temp_Datum
            i_Dateistatus = True

        End If

    End Sub


    Public Function f_Dateiendung_pruefen(Dateiendung As String) As String
        Select Case Dateiendung
            Case "JPG"
                Return "Picture"

            Case "NEF"
                Return "Picture"

            Case "JPEG"
                Return "Picture"

            Case "PNG"
                Return "Picture"

            Case "TIFF"
                Return "Picture"

            Case "BMP"
                Return "Picture"

            Case "MP4"
                Return "Movie"

            Case Else
                Return "NoSupport"

        End Select

    End Function


    Private Function f_GetPictureCreationDateOf(FileInfo As FileInfo) As Date
        Dim RawDate = f_GetExtendedProperty(FileInfo, 12).Split(" "c)(0)
        Dim ClearData = RawDate.Replace(Convert.ToChar(8206), "")
        ClearData.Replace(Convert.ToChar(8207), "")

        Try
            Return Date.Parse(ClearData)
        Catch ex As Exception
            Return Date.Parse("02.01.1900")
        End Try

    End Function

    Private Function f_GetMovieCreationDateOf(FileInfo As FileInfo) As Date
        Dim RawDate = f_GetExtendedProperty(FileInfo, 208).Split(" "c)(0)
        Dim ClearData = RawDate.Replace(Convert.ToChar(8206), "")
        ClearData.Replace(Convert.ToChar(8207), "")

        Try
            Return Date.Parse(ClearData)
        Catch ex As Exception
            Return Date.Parse("02.01.1900")
        End Try

    End Function

    Private Function f_GetExtendedProperty(FileInfo As FileInfo, Position As Integer) As String
        Dim Folder = New Shell32.Shell().NameSpace(FileInfo.DirectoryName)
        Dim FolderItem2 = DirectCast(Folder.Items().Item(FileInfo.Name), Shell32.FolderItem2)
        Return Folder.GetDetailsOf(FolderItem2, Position)
    End Function


End Class
